Manta Dashboard

Select a job to view details

##

Select an assistant to view details

### Skills

Name | Category | Version | Source | Builtin | Status
--- | --- | --- | --- | --- | ---

### Workspaces

Name | Cluster | Status | Created
--- | --- | --- | ---

### Clusters

Name | Status | Created
--- | --- | ---

### Schedules

Name | Cron | Status | Created
--- | --- | --- | ---

Drop JSONL file to view session

## Login to Manta

Username
Password